AbortHandle

Struct AbortHandle 

pub struct AbortHandle { /* private fields */ }
An abort handle, used to forcibly cancel update engine executions.

Implementations

Source

impl AbortHandle

pub fn abort(&self, message: impl Into<String>) -> Result<AbortWaiter, String>

Aborts this engine execution with a message.

This sends the message immediately, and returns a future that can be optionally waited against to block until the abort is processed.

If this engine is still running, it is aborted at the next await point. The engine sends an ExecutionAborted message over the wire, and an ExecutionError::Aborted is returned.

Returns Err(message) if the engine has already completed execution.