pub struct CompletionContext<S: EngineSpec> { /* private fields */ }Expand description
Context returned by a successful
UpdateEngine::execute.
This can be used to retrieve the value of a StepHandle. In the
future, it may also be extended to provide more information.
Implementations
Sourceimpl<S: EngineSpec> CompletionContext<S>
impl<S: EngineSpec> CompletionContext<S>
Sourcepub fn token(&self) -> &StepHandleToken<S>
pub fn token(&self) -> &StepHandleToken<S>
Retrieves a token used to fetch the value out of a
StepHandle.