ComponentRegistrar

Struct ComponentRegistrar 

pub struct ComponentRegistrar<'engine, 'a, S: EngineSpec> { /* private fields */ }
Provides component context against which a step can be registered.

Implementations

Source

impl<'engine, 'a, S: EngineSpec> ComponentRegistrar<'engine, 'a, S>

pub fn component(&self) -> &S::Component

Returns the component associated with this registrar.

pub fn new_step<F, Fut, T>( &self, id: S::StepId, description: impl Into<Cow<'static, str>>, step_fn: F, ) -> NewStep<'engine, 'a, S, T>
where F: FnOnce(StepContext<S>) -> Fut + Send + 'a, Fut: Future<Output = Result<StepResult<T, S>, S::Error>> + Send + 'a, T: Send + 'a,

Adds a new step corresponding to the component associated with the registrar.

Notes

The step will be considered to keep running until both the future completes and the StepContext is dropped. In normal use, both happen at the same time. However, it is technically possible to make the StepContext escape the future.

(Ideally, this would be prevented by making the function take a &mut StepContext, but there are limitations in stable Rust which make this impossible to achieve.)