pub struct ExecutionHandle<'a, S: EngineSpec> { /* private fields */ }Expand description
A join handle for an UpdateEngine.
This handle should be awaited to drive and obtain the result of an execution.
Implementations
Sourceimpl<S: EngineSpec> ExecutionHandle<'_, S>
impl<S: EngineSpec> ExecutionHandle<'_, S>
Sourcepub fn abort(&self, message: impl Into<String>) -> Result<AbortWaiter, String>
pub fn abort(&self, message: impl Into<String>) -> Result<AbortWaiter, String>
Aborts this engine execution with a message.
This sends the message immediately, and returns a future that can be optionally waited against to block until the abort is processed.
If this engine is still running, it is aborted at the next
await point. The engine sends an ExecutionAborted message
over the wire, and an ExecutionError::Aborted is returned.
Returns Err(message) if the engine has already completed
execution.
Sourcepub fn abort_handle(&self) -> AbortHandle
pub fn abort_handle(&self) -> AbortHandle
Creates and returns an abort handle for this engine.
An abort handle can be used to forcibly cancel update engine executions.