MetadataContext

Struct MetadataContext 

pub struct MetadataContext<S: EngineSpec> { /* private fields */ }
Context for a step’s metadata-generation function.

This is passed into the function registered to generate a step’s metadata.

Notes

MetadataContext deliberately does not implement Clone, to make it more likely that it is dropped at the same time the future completes.

Implementations

Source

impl<S: EngineSpec> MetadataContext<S>

pub fn token(&self) -> &StepHandleToken<S>

Retrieves a token used to fetch the value out of a StepHandle.