StepContext

Struct StepContext 

pub struct StepContext<S: EngineSpec> { /* private fields */ }
Context for a step’s execution function.

This is passed into the function registered for a step, and can be used to send progress updates as the function continues execution.

Notes

StepContext deliberately does not implement Clone, to make it more likely that it is dropped at the same time the future completes.

Implementations

Source

impl<S: EngineSpec> StepContext<S>

pub async fn send_progress(&self, progress: StepProgress<S>)

Sends a progress update to the update engine.

pub async fn send_nested_report<S2: EngineSpec>( &self, report: EventReport<S2>, ) -> Result<(), NestedEngineError<GenericSpec>>

Sends a report from a nested engine, typically one running on a remote machine.

Returns an error if a StepEventKind::ExecutionFailed event was seen.

pub async fn with_nested_engine<'a, 'this, F, S2>( &'this self, engine_fn: F, ) -> Result<CompletionContext<S2>, NestedEngineError<S2>>
where F: FnOnce(&mut UpdateEngine<'a, S2>) -> Result<(), S2::Error> + Send, S2: EngineSpec + 'a, 'this: 'a,

Creates a nested execution engine.

An individual step can generate other steps: these steps are treated as nested, and carry their own progress.

pub fn token(&self) -> &StepHandleToken<S>

Retrieves a token used to fetch the value out of a StepHandle.